@@ -3,7 +3,7 @@
  * Author: Igor Vlasenko <vlasenko@imath.kiev.ua>
  * Created: Mon Jul 25 15:29:04 2005
  *
- * $Id: exprtool.h,v 1.9 2005/07/28 11:21:29 igor Exp $
+ * $Id: exprtool.h,v 1.11 2005/09/30 11:00:37 igor Exp $
  */
 
 #ifndef _EXPRTOOL_H
@@ -11,18 +11,12 @@
 
 #include "pstring.h"
 
-typedef char exprtype;
-
-#define EXPRINT 'i'
-#define EXPRDBL 'd'
-#define EXPRPSTR 'p'
-
 #define DO_MATHOP(z,op,x,y) switch (z.type=expr_to_int_or_dbl(&x,&y)) { \
 case EXPRINT: z.val.intval=x.val.intval op y.val.intval;break; \
 case EXPRDBL: z.val.dblval=x.val.dblval op y.val.dblval;break; \
 }
 
-#define DO_LOGOP(z,op,x,y) z.type=EXPRINT; switch (expr_to_int_or_dbl(&x,&y)) { \
+#define DO_LOGOP(z,op,x,y) z.type=EXPRINT; switch (expr_to_int_or_dbl_logop(&x,&y)) { \
 case EXPRINT: z.val.intval=x.val.intval op y.val.intval;break; \
 case EXPRDBL: z.val.intval=x.val.dblval op y.val.dblval;break; \
 }
@@ -39,27 +33,27 @@ case EXPRDBL: z.val.intval=x.val.dblval op y.val.dblval;break; \
 
 #define DO_TXTOP(z,op,x,y) expr_to_str(&x,&y); z.type=EXPRINT; z.val.intval = op (x.val.strval,y.val.strval);
 
-
-struct exprval {
-  exprtype type;
-  union uval {
-    int  intval; 		/* integer */
-    double dblval;		/* double */
-    PSTRING strval;
-  } val;
-};
-
+static
 exprtype expr_to_int_or_dbl (struct exprval* val1, struct exprval* val2);
+static
+exprtype expr_to_int_or_dbl_logop (struct exprval* val1, struct exprval* val2);
+static
 void expr_to_dbl (struct exprval* val1, struct exprval* val2);
+static
 void expr_to_int (struct exprval* val1, struct exprval* val2);
+static
 void expr_to_dbl1 (struct exprval* val);
+static
 void expr_to_str (struct exprval* val1, struct exprval* val2);
+static
 void expr_to_num (struct exprval* val1);
+static
+void expr_to_bool (struct exprval* val1);
+static
 struct exprval exp_read_number (char* *curposptr, char* endchars);
 
-void expnum_debug (struct exprval val, char* msg);
-
 /* this stuff is defined or used in expr.y */
+static
 void expr_debug(char const *,char const *);
 
 /* 
